==> bplan-base-globals-1.26.0-14b028.zip: config/setup.php <==
<?php
/**
 * Global Configuration
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Config
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <https://www.bplan-solutions.de/>
 * /Δ\
 */

return [
    'publish' => [
        'always' => [
            'etc/setup/src/.gitignore'                                                              => '.gitignore',
            // 'etc/setup/src/app/Http/Controllers/.gitignore'                                         => 'app/Http/Controllers/.gitignore',
            'etc/setup/src/composer.local.json.in'                                                  => 'composer.local.json.in',
            // 'etc/setup/src/config/jsonapi.php'                                                      => 'config/jsonapi.php',
            'etc/setup/src/database/.gitignore'                                                     => 'database/.gitignore',
            'etc/setup/src/database/migrations/0000_01_01_000050.globals.create_settings_table.php' => 'database/migrations/0000_01_01_000050.globals.create_settings_table.php',
            'etc/setup/src/database/migrations/0001_01_01_000000_create_users_table.php'            => 'database/migrations/0001_01_01_000000_create_users_table.php',

            // 'etc/setup/src/missing.txt' => 'missing.txt',
        ],
        'once' => [
            'etc/setup/src/app/Exceptions/Handler.php'             => 'app/Exceptions/Handler.php',
            'etc/setup/src/app/Http/Controllers/Controller.php'    => 'app/Http/Controllers/Controller.php',
            'etc/setup/src/app/Models/Setting.php'                 => 'app/Models/Setting.php',
            'etc/setup/src/app/Models/User.php'                    => 'app/Models/User.php',
            // 'etc/setup/src/app/Providers/AppServiceProvider.php'   => 'app/Providers/AppServiceProvider.php',
            'etc/setup/src/app/Repositories/SettingRepository.php' => 'app/Repositories/SettingRepository.php',
            'etc/setup/src/app/Services/SettingService.php'        => 'app/Services/SettingService.php',
            'etc/setup/src/bootstrap/app.php'                      => 'bootstrap/app.php',
            'etc/setup/src/database/seeders/DatabaseSeeder.php'    => 'database/seeders/DatabaseSeeder.php',
            'etc/setup/src/database/seeders/Dev/DevEnvSeeder.php'  => 'database/seeders/Dev/DevEnvSeeder.php',
            'etc/setup/src/routes/api.php'                         => 'routes/api.php',
            'etc/setup/src/routes/web.php'                         => 'routes/web.php',

            'etc/setup/src/config/project.php'                     => 'config/project.php',
        ],
    ],

];

==> bplan-base-globals-1.34.0-ba8099.zip: config/setup.php <==
<?php
/**
 * Global Configuration
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Config
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <https://www.bplan-solutions.de/>
 * /Δ\
 */

return [
    'publish' => [
        'always' => [
            'etc/setup/src/.editorconfig'                                                           => '.editorconfig',
            'etc/setup/src/.gitignore'                                                              => '.gitignore',
            // 'etc/setup/src/app/Http/Controllers/.gitignore'                                         => 'app/Http/Controllers/.gitignore',
            'etc/setup/src/composer.local.json.in'                                                  => 'composer.local.json.in',
            // 'etc/setup/src/config/jsonapi.php'                                                      => 'config/jsonapi.php',
            'etc/setup/src/database/.gitignore'                                                     => 'database/.gitignore',
            'etc/setup/src/database/migrations/0000_01_01_000050.globals.create_settings_table.php' => 'database/migrations/0000_01_01_000050.globals.create_settings_table.php',
            'etc/setup/src/database/migrations/0001_01_01_000000_create_users_table.php'            => 'database/migrations/0001_01_01_000000_create_users_table.php',
            'etc/setup/src/resources/js/dark-switch.js'                                             => 'resources/js/dark-switch.js',

            // 'etc/setup/src/missing.txt' => 'missing.txt',
        ],
        'once' => [
            'tailwind.config.js'                                   => 'tailwind.config.js',
            'etc/setup/src/.editorconfig'                          => '.editorconfig',
            'etc/setup/src/app/Exceptions/Handler.php'             => 'app/Exceptions/Handler.php',
            'etc/setup/src/app/Http/Controllers/Controller.php'    => 'app/Http/Controllers/Controller.php',
            'etc/setup/src/app/Models/Setting.php'                 => 'app/Models/Setting.php',
            'etc/setup/src/app/Models/User.php'                    => 'app/Models/User.php',
            // 'etc/setup/src/app/Providers/AppServiceProvider.php'   => 'app/Providers/AppServiceProvider.php',
            'etc/setup/src/app/Repositories/SettingRepository.php' => 'app/Repositories/SettingRepository.php',
            'etc/setup/src/app/Services/SettingService.php'        => 'app/Services/SettingService.php',
            'etc/setup/src/app/View/Components/AppLayout.php'      => 'app/View/Components/AppLayout.php',
            'etc/setup/src/bootstrap/app.php'                      => 'bootstrap/app.php',
            'etc/setup/src/database/seeders/DatabaseSeeder.php'    => 'database/seeders/DatabaseSeeder.php',
            'etc/setup/src/database/seeders/Dev/DevEnvSeeder.php'  => 'database/seeders/Dev/DevEnvSeeder.php',
            'etc/setup/src/resources/js/app.js'                    => 'resources/js/app.js',
            'etc/setup/src/routes/api.php'                         => 'routes/api.php',
            'etc/setup/src/routes/web.php'                         => 'routes/web.php',

            'etc/setup/src/config/project.php'                     => 'config/project.php',
        ],
    ],

];
